@@ -24,7 +24,7 @@ def __start() -> None:
     from .version import ver
     from ..version import ver as fxxkpy_ver
 
-    content = JY if randint(0, 97) else I_LIKE_JY
+    content = JY if randint(1, 97) - 1 else I_LIKE_JY
     color = '' if not randint(0, 2) else Fore.GREEN if not randint(0, 4) else Fore.YELLOW if randint(0, 1) else Fore.BLUE
     print(f"{color}JY {ver} (FxxkPy {fxxkpy_ver})")
     print(content, end='')
