@@ -1,9 +1,11 @@
 # coding:utf-8
 from .error import *
+from .FullBaseObject import *
+from .FullFunction import *
 from .game import *
+from .he import HE
 from .languages import *
 from .math import *
-from .FullBaseObject import *
 from .remove import *
 from .start import *
 from .vector import *
