@@ -1,13 +1,10 @@
 # coding:utf-8
-from types import NoneType as _NoneType
-
-
 # 动态壁纸
 class Dynamic(object):
     '''
     Windows下的动态壁纸类
 
-    只有x86架构的64位Windows可以运行，其他系统会报错
+    只有x86架构的64位Windows可以运行, 其他系统会报错
 
     self.start 方法开始显示壁纸
 
@@ -15,8 +12,8 @@ class Dynamic(object):
 
     属性:
         video: 视频绝对路径
-        player: ffplay 播放器的绝对路径，$default 为 \\wallpaper\\ffplay 下的 ffplay.exe
-        command: 运行参数，$default 为默认参数，如果改变了参数，可以用 $video 代替视频绝对路径
+        player: ffplay 播放器的绝对路径, $default 为 \\wallpaper\\ffplay 下的 ffplay.exe
+        command: 运行参数, $default 为默认参数, 如果改变了参数, 可以用 $video 代替视频绝对路径
         SetDpi: 改变缩放设置需要用的程序
         userdpi: self.__getdpi 函数获取到的 dpi
         stop_threads: 停止线程的参数
@@ -25,25 +22,28 @@ class Dynamic(object):
         main_thread: 主线程
 
     注意:
-        程序运作是可能会改变缩放率，忽略即可，程序运行要十秒左右的时间，最好啥都不干
+        程序运作是可能会改变缩放率, 忽略即可, 程序运行要十秒左右的时间, 最好啥都不干
     '''
     def __init__(self, video: str, player: str = "$default", command: str = "$default") -> None:
         # 导入库
         import os as __os
-        import time as __time
         import platform as __platform
         import threading as __threading
+        import time as __time
+
         import win32api as __win32api
-        import win32gui as __win32gui
         import win32con as __win32con
+        import win32gui as __win32gui
         import win32print as __win32print
+
         self.__os = __os
-        self.__time = __time
         self.__platform = __platform
         self.__threading = __threading
+        self.__time = __time
+
         self.__win32api = __win32api
-        self.__win32gui = __win32gui
         self.__win32con = __win32con
+        self.__win32gui = __win32gui
         self.__win32print = __win32print
         # 判断系统是否为x86架构的64位Windows
         if self.__platform.system() == "Windows" and self.__platform.machine() == "AMD64":
@@ -99,7 +99,7 @@ class Dynamic(object):
         self.__os.popen(f"{self.player} {self.command}")
 
     # 隐藏WorkerW
-    def __hide(self, hwnd: int, hwnds: _NoneType) -> None:
+    def __hide(self, hwnd: int, hwnds: None) -> None:
         hdef = self.__win32gui.FindWindowEx(hwnd, 0, "SHELLDLL_DefView", None)  # 枚举窗口寻找特定类
         if hdef != 0:
             workerw = self.__win32gui.FindWindowEx(0, hwnd, "WorkerW", None)  # 找到hdef后寻找WorkerW
@@ -115,15 +115,15 @@ class Dynamic(object):
         self.__win32gui.SendMessageTimeout(progman, 0x52C, 0, 0, 0, 0)  # 发送0x52C消息
         videowin = self.__win32gui.FindWindow("SDL_app", None)  # 寻找ffplay 播放窗口
         self.__win32gui.SetParent(videowin, progman)  # 设置子窗口
-        self.__win32gui.EnumWindows(self.__hide, None)  # 枚举窗口，回调hide函数
+        self.__win32gui.EnumWindows(self.__hide, None)  # 枚举窗口, 回调hide函数
 
     # 主函数
     def __main(self) -> None:
-        self.__time.sleep(1)
+        self.__time.sleep(0.5)
         self.display_thread = self.__threading.Thread(target=self.__display, daemon=True)
         self.back_thread = self.__threading.Thread(target=self.__back, daemon=True)
         self.display_thread.start()
-        self.__time.sleep(1)
+        self.__time.sleep(0.5)
         self.back_thread.start()
         while not self.stop_threads:
             pass
